[Cluster-devel] cluster/rgmanager/src/resources netfs.sh

lhh at sourceware.org lhh at sourceware.org
Wed Oct 3 17:01:40 UTC 2007


CVSROOT:	/cvs/cluster
Module name:	cluster
Branch: 	RHEL4
Changes by:	lhh at sourceware.org	2007-10-03 17:01:39

Modified files:
	rgmanager/src/resources: netfs.sh 

Log message:
	Merge netfs.sh from RHEL4 branch; adds cifs support to netfs.sh

Patches:
http://sourceware.org/cgi-bin/cvsweb.cgi/cluster/rgmanager/src/resources/netfs.sh.diff?cvsroot=cluster&only_with_tag=RHEL4&r1=1.1.2.4&r2=1.1.2.5

--- cluster/rgmanager/src/resources/netfs.sh	2007/05/21 15:56:47	1.1.2.4
+++ cluster/rgmanager/src/resources/netfs.sh	2007/10/03 17:01:39	1.1.2.5
@@ -21,7 +21,7 @@
 #
 
 #
 # NFS file system mount/umount/etc. agent
 #
 
 LC_ALL=C
@@ -50,10 +50,10 @@
     <version>1.0</version>
 
     <longdesc lang="en">
-        This defines an NFS mount for use by cluster services.
+        This defines an NFS/CIFS mount for use by cluster services.
     </longdesc>
     <shortdesc lang="en">
-        Defines an NFS file system mount.
+        Defines an NFS/CIFS file system mount.
     </shortdesc>
 
     <parameters>
@@ -79,7 +79,7 @@
 
         <parameter name="host" required="1">
 	    <longdesc lang="en">
-	    	NFS Server IP address or hostname
+	    	Server IP address or hostname
 	    </longdesc>
             <shortdesc lang="en">
 	    	IP or Host
@@ -89,7 +89,7 @@
 
         <parameter name="export" required="1">
 	    <longdesc lang="en">
-	    	NFS Export directory name
+	    	NFS Export directory name or CIFS share
 	    </longdesc>
             <shortdesc lang="en">
 	    	Export
@@ -99,10 +99,10 @@
 
         <parameter name="fstype" required="0">
 	    <longdesc lang="en">
-	    	NFS File System type (nfs or nfs4)
+	    	File System type (nfs, nfs4 or cifs)
 	    </longdesc>
             <shortdesc lang="en">
-	    	NFS File System Type
+	    	File System Type
             </shortdesc>
 	    <content type="string"/>
         </parameter>
@@ -194,7 +194,7 @@
 verify_host()
 {
 	if [ -z "$OCF_RESKEY_host" ]; then
-	       ocf_log err "No server hostname or IP addess specified."
+	       ocf_log err "No server hostname or IP address specified."
 	       return 1
 	fi
 
@@ -215,7 +215,7 @@
 	[ -z "$OCF_RESKEY_fstype" ] && return 0
 
 	case $OCF_RESKEY_fstype in
-	nfs|nfs4)
+	nfs|nfs4|cifs)
 		return 0
 		;;
 	*)
@@ -247,6 +247,9 @@
 		esac
 
 		case $OCF_RESKEY_fstype in
+		cifs)
+			continue
+			;;
 		nfs|nfs4)
 			case $o in
 			#
@@ -374,7 +377,6 @@
 	    	return $FAIL
 	    	;;
 	esac
-	
 	#
 	# Get the device
 	#
@@ -432,7 +434,16 @@
 	# Mount the NFS export
 	#
 	ocf_log debug "mount $fstype_option $mount_options $fullpath $mp"
-	mount $fstype_option $mount_options $fullpath $mp
+
+        case $OCF_RESKEY_fstype in
+		nfs|nfs4)
+			mount -t $OCF_RESKEY_fstype $mount_options $host:$exp $mp
+			;;
+		cifs)
+			mount -t $OCF_RESKEY_fstype $mount_options //$host/$exp $mp
+			;;
+	esac
+
 	ret_val=$?
 	if [ $ret_val -ne 0 ]; then
 		ocf_log err "\
@@ -21,7 +21,7 @@
 
 #
-# NFS file system mount/umount/etc. agent
+# NFS/CIFS file system mount/umount/etc. agent
 #
 




More information about the Cluster-devel mailing list